@@ -65,6 +65,7 @@ class Container(Node):
             self._empty = False
             self.__dict__[name] = value
             self.__dict__[name]._name = name
+            self.__dict__[name]._name = self._xmlify(name)
             return
 
         caller = inspect.currentframe().f_back
@@ -336,6 +337,9 @@ class List(Node):
         self._values[key] = value
         self._values[key]._name = self._xmlify(self._name)
 
+    def __delitem__(self, key):
+        del self._values[key]
+
     @property
     def is_empty(self):
         return not (bool(len(self.keys())))
